<?php
// w肳ꂽt@C\
?>
<?php
// t@C쐬
$filename = $MOWIKI_DATA.$gIn['title'].'.txt';

// t@C̑݃`FbN
if (!file_exists($filename)) {
  if (decode($gIn['title']) == $MOWIKI_FRONTPAGE) {
	// gbv̏ꍇ́AҏWɓȂ
	$gOut['body'] = '<i><b>'.decode($gIn['title'])."</b></i>";
	$gOut['edit'] = 1;
  } else {
	// VK[h
	require($MOWIKI_LIB.'newpage.php');
  }
  
  require($MOWIKI_VIEW.'template.php');
  exit;
}

// t@Cǂݍ
$fp = fopen($filename, 'r');
$i = 0;

while(!feof($fp)) {
  $contents[$i] .= fgets($fp, 1024);

  // shttp://̏ꍇAsŜNɂB
  if (preg_match("/^http:\/\//", $contents[$i])) {
 	$contents[$i] = '<a href="'.$contents[$i].'">'.$contents[$i].'</a>';
  }
  
  $i++;
}
fclose($fp);

// ^Õ_O
$i = 0;
while (strlen($contents[$i]) > 0) {

  // MOWIKI_LI0Ŏn܂ĂꍇA<li>ɕϊB
  if (preg_match("/^$MOWIKI_LI0/", $contents[$i])) {
	
	if ($LI0_MODE == '1') { // li^OɓĂꍇ
	  
	  if (preg_match("/^$MOWIKI_LI0/", $contents[($i + 1)])) { // ̍sliwȂ
		// Ȃ
	  } else {
		// liIB
		$contents[($i + 1)] = '</ul>'.$contents[($i + 1)];
	  }
	  
	} else { // li^O̊Oꍇ
	  // li^Oɓ  
	  $contents[($i - 1)] .= '<ul>';
	  $LI0_MODE = 1;
	  
	}
	
	$contents[$i] = preg_replace("/^$MOWIKI_LI0/", '<li>', $contents[$i]);
  }

  // <hr>
  if (preg_match("/^$MOWIKI_HR(\r\n|\n)/", $contents[$i])) {
	$contents[$i] = '<hr color="'.$MOWIKI_HR_COLOR.'">';
  }

  $i++;
}

// ϊς݂̃y[We
$i = 0;
while (strlen($contents[$i]) > 0) {
  if (preg_match('/^<li>/', $contents[($i - 1)])) {
	$tmp .= "\n".$contents[$i];
  } else if (preg_match("/^<hr.+>/", $contents[($i - 1)])) {
	$tmp .= "\n".$contents[$i];
  } else {
	$tmp .= "<br>\n".$contents[$i];
  }
  $i++;
}

// $contents = ereg_replace("\n", "<br>\n", $contents);

// \pϐ
// $tmp = implode('<br>', $contents);
$gOut['body'] = '<i><b>'.decode($gIn['title'])."</b></i><br>\n".$tmp;
?>